@@ -1,11 +1,10 @@
-from nonebot import on_message, get_driver, on_regex
+from nonebot import on_message, get_driver
 from nonebot.plugin import PluginMetadata
 from nonebot.adapters.onebot.v11.message import MessageSegment
 from nonebot.adapters.onebot.v11 import Bot, MessageEvent
 from nonebot.exception import ActionFailed, NetworkError
 from nonebot.log import logger
 from nonebot.permission import SUPERUSER
-from nonebot.typing import T_State
 from nonebot import require
 require("nonebot_plugin_apscheduler")
 from nonebot_plugin_apscheduler import scheduler
@@ -34,14 +33,14 @@ __plugin_meta__ = PluginMetadata(
     description="基于nonebot2和vits的本地化角色语音合成插件",
     usage=f"触发方式：{trigger_rule}[角色名][发送|说][文本内容]\n"+
         "※超级用户管理(若设置前缀，以下均加上前缀)\n"+
-        "   [禁用翻译 xxx]   禁用xxx翻译项\n"+
-        "   [启用翻译 xxx]   启用xxx翻译项\n"+
-        "   [查看翻译]         查看目前可用的翻译项\n"+
-        "   [查看禁用翻译]  查看已被禁用的翻译项",
+        f"   {trigger_rule}[禁用翻译 xxx]   禁用xxx翻译项\n"+
+        f"   {trigger_rule}[启用翻译 xxx]   启用xxx翻译项\n"+
+        f"   {trigger_rule}[查看翻译]         查看目前可用的翻译项\n"+
+        f"   {trigger_rule}[查看禁用翻译]  查看已被禁用的翻译项",
     extra={
         "example": f"{trigger_rule} 宁宁说おはようございます.",
         "author": "dpm12345 <1006975692@qq.com>",
-        "version": "0.3.7",
+        "version": "0.3.8",
     },
 )
 
@@ -79,10 +78,10 @@ def _():
 
 voice = on_message(
     regex(rf"(?:{prefix} *)(?P<name>.+?)(?:说|发送)(?P<text>.+?)$"), block=False, priority=priority)
-lock_tran = on_regex(rf"(?:{prefix} *)禁用翻译(?: *)(?P<tran>.+)$",flags=re.I,permission=SUPERUSER,block=False,priority=priority)
-unlock_tran = on_regex(rf"(?:{prefix} *)启用翻译(?: *)(?P<tran>.+)$",flags=re.I,permission=SUPERUSER,block=False,priority=priority)
-show_trans = on_regex(rf"(?:{prefix} *)查看翻译(?: *)$",flags=re.I,permission=SUPERUSER,block=False,priority=priority)
-show_lock_trans = on_regex(rf"(?:{prefix} *)查看禁用翻译(?: *)$",flags=re.I,permission=SUPERUSER,block=False,priority=priority)
+lock_tran = on_message(regex(rf"(?:{prefix} *)禁用翻译(?: *)(?P<tran>.+)$"), permission=SUPERUSER,block=False,priority=priority)
+unlock_tran = on_message(regex(rf"(?:{prefix} *)启用翻译(?: *)(?P<tran>.+)$"), permission=SUPERUSER,block=False,priority=priority)
+show_trans = on_message(regex(rf"(?:{prefix} *)查看翻译(?: *)$"), permission=SUPERUSER,block=False,priority=priority)
+show_lock_trans = on_message(regex(rf"(?:{prefix} *)查看禁用翻译(?: *)$"), permission=SUPERUSER,block=False,priority=priority)
 
 @voice.handle()
 async def voicHandler(
@@ -152,20 +151,19 @@ async def voicHandler(
             os.remove(new_voice)
 
 @lock_tran.handle()
-async def _(state:T_State):
-    tran = state["_matched_dict"]['tran']
+async def _(tran: str = RegexArg("tran")):
     if tran == "youdao":
         await lock_tran.send(f"该翻译项禁止禁用!")
     elif tran in tran_type:
-        lock_tran_list["manual"].extend([tran])
+        if tran not in lock_tran_list["manual"]:
+            lock_tran_list["manual"].append(tran)
         logger.info(f"禁用成功")
         await lock_tran.send(f"禁用成功")
     else:
         await lock_tran.send(f"未有{tran}翻译项")
 
 @unlock_tran.handle()
-async def _(state:T_State):
-    tran = state["_matched_dict"]['tran']
+async def _(tran: str = RegexArg("tran")):
     if tran in lock_tran_list["auto"] or tran in lock_tran_list["manual"]:
         if tran in lock_tran_list["auto"]:
             lock_tran_list["auto"].remove(tran)
@@ -187,7 +185,9 @@ async def _():
 @show_lock_trans.handle()
 async def _():
     lock_list = lock_tran_list["auto"].copy()
-    lock_list.extend(lock_tran_list["manual"])
+    for tran in lock_tran_list["manual"]:
+        if tran not in lock_list:
+            lock_list.append(tran)
     if len(lock_list) == 0:
         await show_lock_trans.send("目前没有翻译项被禁用")
     else:
@@ -198,4 +198,4 @@ async def _():
 async def reset_tran():
     lock_tran_list["auto"].clear()
     valid_tran_type = [tran for tran in tran_type if tran not in lock_tran_list["manual"]]
-    logger.info(f"目前可用翻译:{','.join(valid_tran_type)}")
\ No newline at end of file
+    logger.info(f"目前可用翻译:{','.join(valid_tran_type)}")
